﻿using AngleSharp;
using AngleSharp.Dom;
using AngleSharp.Html.Dom;
using AngleSharp.Html.Parser;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DeskTopMascot
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        private MessageWindow messageWindow;
        private CoronaWindow colonaWindow;
        private IHtmlDocument coronaInfo;

        public MainWindow()
        {
            InitializeComponent();

            messageWindow = new MessageWindow();
            colonaWindow = new CoronaWindow();
        }

        private void GetCoronaInfo()
        {
            var urlstring = "https://tenki.jp/forecast/6/29/6110/26106/";
            var req = (HttpWebRequest)WebRequest.Create(urlstring);
            using (var res = (HttpWebResponse)req.GetResponse())
            using (var stream = res.GetResponseStream())
            using (var sr = new StreamReader(stream))
            {
                var text = sr.ReadToEnd();
                var parser = new HtmlParser();
                coronaInfo = parser.ParseDocument(text);
            }
        }

        // ↓非同期なら以下
        //private async void GetCoronaInfo()
        //{
        //    var urlstring = "https://tenki.jp/forecast/6/29/6110/26106/";

        //    var doc = default(IHtmlDocument);
        //    using (var client = new HttpClient())
        //    using (var stream = await client.GetStreamAsync(new Uri(urlstring)))
        //    {
        //        var parser = new HtmlParser();
        //        doc = await parser.ParseDocumentAsync(stream);
        //        coronaInfo = doc;
        //    }
        //}

        private void Hi_Click(object sender, RoutedEventArgs e)
        {
            messageWindow.SetTopLeft(this.Top + 30, this.Left - 210);
            messageWindow.Show();
            messageWindow.DisplayMessage();
        }

        private void Corona_Click(object sender, RoutedEventArgs e)
        {
            GetCoronaInfo();
            colonaWindow.SetTopLeft(this.Top + 120, this.Left - 210);
            colonaWindow.Show();
            colonaWindow.DisplayTitle(coronaInfo);
        }

        private void End_Click(object sender, RoutedEventArgs e)
        {
            messageWindow.Close();
            colonaWindow.Close();
            Close();
        }

        protected override void OnMouseLeftButtonDown(MouseButtonEventArgs e)
        {
            base.OnMouseLeftButtonDown(e);
            DragMove();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            // 画面右下に配置
            var desktopWorkingArea = System.Windows.SystemParameters.WorkArea;
            this.Left = desktopWorkingArea.Right - this.Width;
            this.Top = desktopWorkingArea.Bottom - this.Height;
        }
    }
}
